package IO::K8s::Api::Storage::V1::VolumeAttachmentSpec;
# ABSTRACT: VolumeAttachmentSpec is the specification of a VolumeAttachment request.
our $VERSION = '1.007';
use IO::K8s::Resource;

k8s attacher => Str, 'required';


k8s nodeName => Str, 'required';


k8s source => 'Storage::V1::VolumeAttachmentSource', 'required';


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Storage::V1::VolumeAttachmentSpec - VolumeAttachmentSpec is the specification of a VolumeAttachment request.

=head1 VERSION

version 1.007

=head2 attacher

attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().

=head2 nodeName

nodeName represents the node that the volume should be attached to.

=head2 source

source represents the volume that should be attached.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
