package IO::K8s::Api::Core::V1::PersistentVolumeClaimCondition;
# ABSTRACT: PersistentVolumeClaimCondition contains details about state of pvc
our $VERSION = '1.007';
use IO::K8s::Resource;

k8s lastProbeTime => Time;


k8s lastTransitionTime => Time;


k8s message => Str;


k8s reason => Str;


k8s status => Str, 'required';

k8s type => Str, 'required';

1;

__END__

=pod

=encoding UTF-8

=head1 NAME

IO::K8s::Api::Core::V1::PersistentVolumeClaimCondition - PersistentVolumeClaimCondition contains details about state of pvc

=head1 VERSION

version 1.007

=head2 lastProbeTime

lastProbeTime is the time we probed the condition.

=head2 lastTransitionTime

lastTransitionTime is the time the condition transitioned from one status to another.

=head2 message

message is the human-readable message indicating details about last transition.

=head2 reason

reason is a unique, this should be a short, machine understandable string that gives the reason for condition's last transition. If it reports "Resizing" that means the underlying persistent volume is being resized.

=head1 SUPPORT

=head2 Issues

Please report bugs and feature requests on GitHub at
L<https://github.com/pplu/io-k8s-p5/issues>.

=head2 IRC

Join C<#kubernetes> on C<irc.perl.org> or message Getty directly.

=head1 CONTRIBUTING

Contributions are welcome! Please fork the repository and submit a pull request.

=head1 AUTHORS

=over 4

=item *

Torsten Raudssus <torsten@raudssus.de>

=item *

Jose Luis Martinez <jlmartin@cpan.org> (original author, inactive)

=back

=head1 COPYRIGHT AND LICENSE

This software is Copyright (c) 2018 by Jose Luis Martinez.

This is free software, licensed under:

  The Apache License, Version 2.0, January 2004

=cut
